@@ -56,8 +56,6 @@ def get_data(save_dataset_fd,documents):
     torch.save(train_data, train_data_dataset_path)
     torch.save(test_data, test_data_dataset_path)
 
-    return save_dataset_fd
-
 def makeIndividualData(file):
     connect = Grapher(file)
     G, _, _ = connect.graph_formation()
@@ -80,12 +78,12 @@ def makeIndividualData(file):
             pass
 
     df['Tag'] = df['Tag'].fillna('undefined')
-    df.loc[df['Tag'] == 'company', 'num_labels'] = 1
-    df.loc[df['Tag'] == 'address', 'num_labels'] = 2
-    df.loc[df['Tag'] == 'date', 'num_labels'] = 3
-    df.loc[df['Tag'] == 'total', 'num_labels'] = 4
-    df.loc[df['Tag'] == 'invoice', 'num_labels'] = 5
-    df.loc[df['Tag'] == 'undefined', 'num_labels'] = 6
+    #df.loc[df['Tag'] == 'company', 'num_labels'] = 1
+    #df.loc[df['Tag'] == 'address', 'num_labels'] = 2
+    #df.loc[df['Tag'] == 'date', 'num_labels'] = 3
+    #df.loc[df['Tag'] == 'total', 'num_labels'] = 4
+    #df.loc[df['Tag'] == 'invoice', 'num_labels'] = 5
+    df.loc[df['Tag'] == 'undefined', 'num_labels'] = 1
 
     assert df[
                'num_labels'].isnull().values.any() == False, f'labeling error! Invalid label(s) present in {file}.csv, df:{df}'
