@@ -4,12 +4,14 @@ from graphmanagerlib.Inference import predictionsUnique
 
 
 class GraphManager:
-    def __init__(self, documents, save_dataset_fd):
-        self.save_dataset_path = get_data(documents=documents, save_dataset_fd=save_dataset_fd)
+    def __init__(self, documents, save_dataset_fd,nb_classes):
+        self.save_dataset_path = save_dataset_fd
+        self.nb_classes = nb_classes
+        get_data(documents=documents, save_dataset_fd=save_dataset_fd)
 
     def CreateTrainAndSaveGCN(self):
         traindata, testdata = load_train_test_split(self.save_dataset_path)
-        CreateTrainAndSaveGCN(traindata, testdata, self.save_dataset_path)
+        CreateTrainAndSaveGCN(traindata, testdata, self.save_dataset_path, self.nb_classes)
         print("===== Modèle entrainé et sauvegardé =====")
 
     def single_prediction(self, saved_model_folder, prediction_dataset_folder, document_to_predict, labels_tab):
