@@ -14,9 +14,6 @@ def clearOutputFolder(test_output_fd):
         os.mkdir(test_output_fd)
 
 
-save_modelPath = os.path.join("C:\\AsianGCN\\saved_model\\saved_model.pt")
-model = torch.load(save_modelPath)
-
 def make_info(document):
     connect = Grapher(document)
     G, _, _ = connect.graph_formation()
