@@ -15,7 +15,7 @@ def ConvertJsonToDocumentsObjects(json):
         nodes = i["Nodes"]
         listOfNodes = []
         for j in nodes:
-            node = Node(XMin=j["XMin"], YMin=j["YMin"], XMax=j["XMax"], YMax=j["YMax"], Tag=j["Tag"])
+            node = Node(XMin=j["XMin"], YMin=j["YMin"], XMax=j["XMax"], YMax=j["YMax"], Object= j["Object"], Tag=j["Tag"])
             listOfNodes.append(node)
         doc = Document(index=index, nodes=listOfNodes)
         listOfDocuments.append(doc)
